==> mingw-w64-clang-i686-python-contourpy-1.1.1-1-any.pkg.tar.zst: clang32/lib/python3.11/site-packages/contourpy/util/_build_config.py <==
# _build_config.py.in is converted into _build_config.py during the meson build process.

from __future__ import annotations


def build_config() -> dict[str, str]:
    """
    Return a dictionary containing build configuration settings.

    All dictionary keys and values are strings, for example ``False`` is
    returned as ``"False"``.
    """
    return dict(
        # Python settings
        python_version="3.11",
        python_install_dir=r"D:/a/msys64/clang32/lib/python3.11/site-packages/",
        python_path=r"D:/a/msys64/clang32/bin/python.exe",

        # Package versions
        contourpy_version="1.1.1",
        meson_version="1.2.1",
        mesonpy_version="0.14.0",
        pybind11_version="2.11.1",

        # Misc meson settings
        meson_backend="ninja",
        build_dir=r"C:/M/B/src/python-build-CLANG32/.mesonpy-8ir12oj8/lib/contourpy/util",
        source_dir=r"C:/M/B/src/python-build-CLANG32/lib/contourpy/util",
        cross_build="False",

        # Build options
        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md --native-file=C:/M/B/src/python-build-CLANG32/.mesonpy-8ir12oj8/meson-python-native-file.ini",
        buildtype="release",
        cpp_std="c++17",
        debug="False",
        optimization="3",
        vsenv="False",
        b_ndebug="if-release",
        b_vscrt="from_buildtype",

        # C++ compiler
        compiler_name="clang",
        compiler_version="16.0.5",
        linker_id="ld.lld",
        compile_command="clang++",

        # Host machine
        host_cpu="i686",
        host_cpu_family="x86",
        host_cpu_endian="little",
        host_cpu_system="windows",

        # Build machine, same as host machine if not a cross_build
        build_cpu="i686",
        build_cpu_family="x86",
        build_cpu_endian="little",
        build_cpu_system="windows",
    )

==> mingw-w64-clang-i686-python-contourpy-1.2.0-1-any.pkg.tar.zst: clang32/lib/python3.11/site-packages/contourpy/util/_build_config.py <==
# _build_config.py.in is converted into _build_config.py during the meson build process.

from __future__ import annotations


def build_config() -> dict[str, str]:
    """
    Return a dictionary containing build configuration settings.

    All dictionary keys and values are strings, for example ``False`` is
    returned as ``"False"``.

        .. versionadded:: 1.1.0
    """
    return dict(
        # Python settings
        python_version="3.11",
        python_install_dir=r"D:/a/msys64/clang32/lib/python3.11/site-packages/",
        python_path=r"D:/a/msys64/clang32/bin/python.exe",

        # Package versions
        contourpy_version="1.2.0",
        meson_version="1.2.3",
        mesonpy_version="0.15.0",
        pybind11_version="2.11.1",

        # Misc meson settings
        meson_backend="ninja",
        build_dir=r"C:/M/B/src/python-build-CLANG32/.mesonpy-f5pdjb9s/lib/contourpy/util",
        source_dir=r"C:/M/B/src/python-build-CLANG32/lib/contourpy/util",
        cross_build="False",

        # Build options
        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md --native-file=C:/M/B/src/python-build-CLANG32/.mesonpy-f5pdjb9s/meson-python-native-file.ini",
        buildtype="release",
        cpp_std="c++17",
        debug="False",
        optimization="3",
        vsenv="False",
        b_ndebug="if-release",
        b_vscrt="from_buildtype",

        # C++ compiler
        compiler_name="clang",
        compiler_version="17.0.4",
        linker_id="ld.lld",
        compile_command="clang++",

        # Host machine
        host_cpu="i686",
        host_cpu_family="x86",
        host_cpu_endian="little",
        host_cpu_system="windows",

        # Build machine, same as host machine if not a cross_build
        build_cpu="i686",
        build_cpu_family="x86",
        build_cpu_endian="little",
        build_cpu_system="windows",
    )
